@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 2008,2009 Sebastian Pölsterl
+ *
+ * This file is part of GNOME DVB Daemon.
+ *
+ * GNOME DVB Daemon is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * GNOME DVB Daemon is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include <src/ChannelListWriter.h>
 #include <stdlib.h>
@@ -172,7 +190,7 @@ void dvb_channel_list_writer_write (DVBChannelListWriter* self, DVBChannel* chan
 					return;
 				}
 			} else {
-				g_warning ("ChannelListWriter.vala:57: Unknown channel type");
+				g_warning ("ChannelListWriter.vala:76: Unknown channel type");
 			}
 		}
 	}
@@ -321,12 +339,19 @@ static void dvb_channel_list_writer_write_cable_channel (DVBChannelListWriter* s
 static char* dvb_channel_list_writer_get_name_without_prefix (GType enumtype, gint val, const char* prefix) {
 	const char* _tmp0;
 	char* name;
-	char* _tmp1;
 	g_return_val_if_fail (prefix != NULL, NULL);
 	_tmp0 = NULL;
 	name = (_tmp0 = dvb_utils_get_name_by_value_from_enum (enumtype, val), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
-	_tmp1 = NULL;
-	return (_tmp1 = string_substring (name, strlen (prefix), strlen (name) - strlen (prefix)), name = (g_free (name), NULL), _tmp1);
+	if (name == NULL) {
+		char* _tmp1;
+		_tmp1 = NULL;
+		return (_tmp1 = NULL, name = (g_free (name), NULL), _tmp1);
+	} else {
+		char* _tmp2;
+		_tmp2 = NULL;
+		return (_tmp2 = string_substring (name, strlen (prefix), strlen (name) - strlen (prefix)), name = (g_free (name), NULL), _tmp2);
+	}
+	name = (g_free (name), NULL);
 }
 
 
