@@ -19,9 +19,13 @@
 
 #include <src/SqliteConfigTimersStore.h>
 #include <sqlite3.h>
+#include <gee/arraylist.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <gio/gio.h>
+#include <gee/iterable.h>
+#include <gee/iterator.h>
 #include "src/ChannelList.h"
 #include "src/Main.h"
 #include "src/Channel.h"
